@@ -22,7 +22,9 @@ class OwncloudControl:
         protocol = protocol.lower()
         if protocol == 'https':
             self.access.https_on()
-        elif protocol != 'http':
+        elif protocol == 'http':
+            self.access.https_off()
+        else:
             raise Exception('Unknown protocol {}, it should either http or https'.format(protocol))
         self.config_manager.overwrite_webroot()
 
